#[repr(C)]pub struct Params {
pub button: usize,
pub handler_func: extern "C" fn(data: *const u8, state: usize),
pub handler_data: *const u8,
}Expand description
Parameters of register
Fields
Index of the button to listen to.
handler_func: extern "C" fn(data: *const u8, state: usize)Function called on button events.
The function takes its opaque data and the new button state as arguments.
handler_data: *const u8The opaque data to use when calling the handler function.