register

Function register 

pub unsafe fn register(params: Params) -> isize
Available on non-crate feature native only.
Registers a callback when a UART is ready.

It is possible that the callback is spuriously called. The callback is only guaranteed to be called after the associated operation processed less bytes than the buffer size.