#[repr(C)]pub struct Params {
pub uart: usize,
pub event: usize,
pub handler_func: extern "C" fn(data: *const u8),
pub handler_data: *const u8,
}Expand description
Parameters of register
Fields
uart: usizeIndex of the UART to listen to.
event: usizeEvent to listen to.
handler_func: extern "C" fn(data: *const u8)Function pointer of the closure to call on events.
handler_data: *const u8Opaque data of the closure to call on events.